@@ -1,7 +1,6 @@
 # coding=utf-8
 
 import ucenter
-from ucenter.db import mongo as uc_mongo
 
 from webmother.db import mongo
 from webmother import routes
@@ -9,11 +8,8 @@ from webmother import routes
 
 def init(app):
 
-    # 初始化UCenter数据库
-    uc_mongo.init()
-
-    # 加载UCenter API路由
-    app.load_routes(ucenter.routes)
+    # 初始化UCenter
+    ucenter.init(app)
 
     # 初始化本系统数据库
     mongo.init()
