@@ -3,8 +3,11 @@
 import config
 from webmother.http_handler import mine_handler as h
 
-base = '{}/{}/mine'.format(config.VER, config.DOMAIN)
+base = '{}/{}/mine'.format(config.VER, config.PLATFORM)
 routes = [
-    # 获取我的组织列表
+    # 获取我的组织身份列表
     (rf"/{base}/identities", h.MyIdentitiesHandler),
+
+    # 获取我的VIP身份列表
+    (rf"/{base}/vip", h.MyVipHandler),
 ]
