@@ -3,7 +3,7 @@
 import config
 from webmother.http_handler import org_handler as h
 
-base = '{}/{}/org'.format(config.VER, config.DOMAIN)
+base = '{}/{}/org'.format(config.VER, config.PLATFORM)
 routes = [
     # 组织的增删改查
     (rf"/{base}/([a-f0-9]*)", h.OrgHandler),
