@@ -4,8 +4,13 @@ from webmother.service import ctrl_passport
 from asyncio import get_event_loop
 
 
-async def passport_create(cid, oid, pp_meta, *auth_args):
-    args = cid, oid, pp_meta, *auth_args
+async def get_passport_tpl(cid, *auth_args):
+    args = cid, *auth_args
+    return await get_event_loop().run_in_executor(None, ctrl_passport.get_passport_tpl, *args)
+
+
+async def passport_create(cid, oid, passport_json, *auth_args):
+    args = cid, oid, passport_json, *auth_args
     return await get_event_loop().run_in_executor(None, ctrl_passport.passport_create, *args)
 
 
@@ -14,8 +19,8 @@ async def passport_read(cid, oid, *auth_args):
     return await get_event_loop().run_in_executor(None, ctrl_passport.passport_read, *args)
 
 
-async def passport_update(cid, oid, pp_meta, *auth_args):
-    args = cid, oid, pp_meta, *auth_args
+async def passport_update(cid, oid, passport_json, *auth_args):
+    args = cid, oid, passport_json, *auth_args
     return await get_event_loop().run_in_executor(None, ctrl_passport.passport_update, *args)
 
 
@@ -27,4 +32,3 @@ async def passport_remove(cid, oid, *auth_args):
 async def passports_query(cid, *auth_args):
     args = (cid, *auth_args)
     return await get_event_loop().run_in_executor(None, ctrl_passport.passports_query, *args)
-
